Uses of Class
com.docusign.rooms.model.TaskListForCreate
-
Packages that use TaskListForCreate Package Description com.docusign.rooms.api com.docusign.rooms.model -
-
Uses of TaskListForCreate in com.docusign.rooms.api
Methods in com.docusign.rooms.api with parameters of type TaskListForCreate Modifier and Type Method Description TaskListTaskListsApi. createTaskList(String accountId, Integer roomId, TaskListForCreate body)Add a task list to a room based on a task list template..ApiResponse<TaskList>TaskListsApi. createTaskListWithHttpInfo(String accountId, Integer roomId, TaskListForCreate body)Add a task list to a room based on a task list template. -
Uses of TaskListForCreate in com.docusign.rooms.model
Methods in com.docusign.rooms.model that return TaskListForCreate Modifier and Type Method Description TaskListForCreateTaskListForCreate. taskListTemplateId(Integer taskListTemplateId)taskListTemplateId.
-